@@ -31,7 +31,7 @@ class Api():
     flask_bcrypt = None
     app_config=None
 
-    def __init__(self, name, app_config={}, urls=[]):
+    def __init__(self, name, app_config={}):
         #super(ApiRestplus, self).__init__()
         
         self.app = Flask(name, template_folder='templates')
@@ -47,7 +47,7 @@ class Api():
             description='a boilerplate for flask restplus web service',
             format_checker=FormatChecker(formats=["date"])
         )
-        for mod in urls:
+        for mod in app_config["ROUTES"]:
             #full_module_name = "app.controller." + mod["controller"]
             #print(full_module_name)
             #mymodule = importlib.import_module(full_module_name)
