@@ -2,7 +2,7 @@ import os
 from flask_migrate import Migrate, MigrateCommand
 from flask_script import Manager
 from .api import database as db
-
+import importlib
 from dotenv import load_dotenv
 load_dotenv()
 
@@ -21,6 +21,16 @@ class ApiManager():
         with application.app_context():
             from .models import imports
 
+        with application.app_context():
+            """"""
+            arr = os.listdir('app/models')
+            for f in arr:
+                if ".py" in f:
+                    full_module_name = "app.models."+f[0:-3]
+                    #print(full_module_name)
+                    mymodule = importlib.import_module(full_module_name)
+                    #print(mymodule)
+
         @manager.command
         def start():
             application.run(host="0.0.0.0")
