@@ -1,11 +1,8 @@
-from ..api import database  as db
+"""from ..api import database  as db
 import datetime
 from ..database import  TimestampMixin
 
 class BlacklistToken(db.Model, TimestampMixin):
-    """
-    Token Model for storing JWT tokens
-    """
     __tablename__ = 'blacklist_tokens'
 
     id = db.Column(db.Integer, primary_key=True, autoincrement=True)
@@ -26,4 +23,4 @@ class BlacklistToken(db.Model, TimestampMixin):
         if res:
             return True
         else:
-            return False
\ No newline at end of file
+            return False"""
\ No newline at end of file
